Module: Google::Apis::TravelimpactmodelV1
- Defined in:
- lib/google/apis/travelimpactmodel_v1.rb,
lib/google/apis/travelimpactmodel_v1/classes.rb,
lib/google/apis/travelimpactmodel_v1/service.rb,
lib/google/apis/travelimpactmodel_v1/gem_version.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb
Overview
Travel Impact Model API
Travel Impact Model API lets you query travel carbon emission estimates.
Defined Under Namespace
Classes: ComputeFlightEmissionsRequest, ComputeFlightEmissionsResponse, ComputeScope3FlightEmissionsRequest, ComputeScope3FlightEmissionsResponse, ComputeTypicalFlightEmissionsRequest, ComputeTypicalFlightEmissionsResponse, Date, EasaLabelMetadata, EmissionsGramsPerPax, Flight, FlightWithEmissions, Market, ModelVersion, Scope3FlightEmissions, Scope3FlightSegment, TravelImpactModelService, TypicalFlightEmissions
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-travelimpactmodel_v1 gem
"0.14.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.18.0"- REVISION =
Revision of the discovery document this client was generated from
"20260525"- VERSION =
Version of the Travel Impact Model API this client connects to. This is NOT the gem version.
'V1'