Class: Google::Apis::TravelimpactmodelV1::EmissionsMetadata
- Inherits:
-
Object
- Object
- Google::Apis::TravelimpactmodelV1::EmissionsMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/travelimpactmodel_v1/classes.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb
Overview
All additional metadata.
Instance Attribute Summary collapse
-
#easa_label_metadata ⇒ Google::Apis::TravelimpactmodelV1::EasaLabelMetadata
Metadata about the EASA Flight Emissions Label.
-
#emissions_provenance ⇒ Google::Apis::TravelimpactmodelV1::EmissionsProvenance
Information about the provenance of the data used to calculate emissions estimates, including contributing factors and their data sources.
-
#tim_website_emissions_calculator_url ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EmissionsMetadata
constructor
A new instance of EmissionsMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EmissionsMetadata
Returns a new instance of EmissionsMetadata.
407 408 409 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 407 def initialize(**args) update!(**args) end |
Instance Attribute Details
#easa_label_metadata ⇒ Google::Apis::TravelimpactmodelV1::EasaLabelMetadata
Metadata about the EASA Flight Emissions Label.
Corresponds to the JSON property easaLabelMetadata
388 389 390 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 388 def @easa_label_metadata end |
#emissions_provenance ⇒ Google::Apis::TravelimpactmodelV1::EmissionsProvenance
Information about the provenance of the data used to calculate emissions
estimates, including contributing factors and their data sources. In
provenance_entries, provenance_entry_type acts as the "key" identifying the
contributing factor, and there is always only one entry per entry type. The
remaining fields in each entry describe that specific entry type and may or
may not be populated depending on the contributing factor and available data.
Corresponds to the JSON property emissionsProvenance
398 399 400 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 398 def emissions_provenance @emissions_provenance end |
#tim_website_emissions_calculator_url ⇒ String
Output only. Link to the travelimpactmodel.org Emissions Calculator website.
Example: https://travelimpactmodel.org/lookup/flight?itinerary=ZRH-BOS-LX-52-
20261225.
Corresponds to the JSON property timWebsiteEmissionsCalculatorUrl
405 406 407 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 405 def tim_website_emissions_calculator_url @tim_website_emissions_calculator_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
412 413 414 415 416 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 412 def update!(**args) @easa_label_metadata = args[:easa_label_metadata] if args.key?(:easa_label_metadata) @emissions_provenance = args[:emissions_provenance] if args.key?(:emissions_provenance) @tim_website_emissions_calculator_url = args[:tim_website_emissions_calculator_url] if args.key?(:tim_website_emissions_calculator_url) end |