Class: Google::Apis::TravelimpactmodelV1::EmissionsProvenanceEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/travelimpactmodel_v1/classes.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb

Overview

Details about a single contributing factor in emissions calculations. Each entry represents a single factor where provenance_entry_type acts as the key identifying the factor, and the other fields describe it and may or may not be populated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EmissionsProvenanceEntry

Returns a new instance of EmissionsProvenanceEntry.



524
525
526
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 524

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cargo_mass_fraction_dataFloat

Output only. The cargo mass fraction value. If not set, the cargo mass fraction value is not available. Corresponds to the JSON property cargoMassFractionData

Returns:

  • (Float)


457
458
459
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 457

def cargo_mass_fraction_data
  @cargo_mass_fraction_data
end

#cargo_mass_fraction_t100_strategyString

Output only. Strategy for T100 cargo mass fraction. Corresponds to the JSON property cargoMassFractionT100Strategy

Returns:

  • (String)


462
463
464
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 462

def cargo_mass_fraction_t100_strategy
  @cargo_mass_fraction_t100_strategy
end

#data_categoryString

Output only. Data category of the data source. Corresponds to the JSON property dataCategory

Returns:

  • (String)


467
468
469
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 467

def data_category
  @data_category
end

#distance_adjustment_strategyString

Output only. Strategy for distance adjustment. Corresponds to the JSON property distanceAdjustmentStrategy

Returns:

  • (String)


472
473
474
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 472

def distance_adjustment_strategy
  @distance_adjustment_strategy
end

#estimated_flight_distance_kmFixnum

Output only. The estimated distance flown in CCD flight phase in kilometers value calculated using the distance adjustment factor (DAF). If not set, the estimated flight distance value is not available. Corresponds to the JSON property estimatedFlightDistanceKm

Returns:

  • (Fixnum)


479
480
481
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 479

def estimated_flight_distance_km
  @estimated_flight_distance_km
end

#fuel_burn_eea_strategyString

Output only. Strategy for EEA fuel burn. Corresponds to the JSON property fuelBurnEeaStrategy

Returns:

  • (String)


484
485
486
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 484

def fuel_burn_eea_strategy
  @fuel_burn_eea_strategy
end

#load_factors_ch_aviation_strategyString

Output only. Strategy for CH Aviation load factors. Corresponds to the JSON property loadFactorsChAviationStrategy

Returns:

  • (String)


489
490
491
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 489

def load_factors_ch_aviation_strategy
  @load_factors_ch_aviation_strategy
end

#load_factors_dataFloat

Output only. The load factors data value. If not set, the load factors value is not available. Corresponds to the JSON property loadFactorsData

Returns:

  • (Float)


495
496
497
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 495

def load_factors_data
  @load_factors_data
end

#load_factors_t100_strategyString

Output only. Strategy for T100 load factors. Corresponds to the JSON property loadFactorsT100Strategy

Returns:

  • (String)


500
501
502
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 500

def load_factors_t100_strategy
  @load_factors_t100_strategy
end

#provenance_entry_typeString

Output only. The type of the provenance entry. Acts as the "key" identifying the contributing factor; the remaining fields in this message describe it and may or may not be populated. Corresponds to the JSON property provenanceEntryType

Returns:

  • (String)


507
508
509
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 507

def provenance_entry_type
  @provenance_entry_type
end

#seat_area_ratio_iata_strategyString

Output only. Strategy for IATA seat area ratios. Corresponds to the JSON property seatAreaRatioIataStrategy

Returns:

  • (String)


512
513
514
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 512

def seat_area_ratio_iata_strategy
  @seat_area_ratio_iata_strategy
end

#sourceString

Output only. The source of the data. Corresponds to the JSON property source

Returns:

  • (String)


517
518
519
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 517

def source
  @source
end

#source_versionString

Output only. The version of the source data. For example, "2025/04". Corresponds to the JSON property sourceVersion

Returns:

  • (String)


522
523
524
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 522

def source_version
  @source_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 529

def update!(**args)
  @cargo_mass_fraction_data = args[:cargo_mass_fraction_data] if args.key?(:cargo_mass_fraction_data)
  @cargo_mass_fraction_t100_strategy = args[:cargo_mass_fraction_t100_strategy] if args.key?(:cargo_mass_fraction_t100_strategy)
  @data_category = args[:data_category] if args.key?(:data_category)
  @distance_adjustment_strategy = args[:distance_adjustment_strategy] if args.key?(:distance_adjustment_strategy)
  @estimated_flight_distance_km = args[:estimated_flight_distance_km] if args.key?(:estimated_flight_distance_km)
  @fuel_burn_eea_strategy = args[:fuel_burn_eea_strategy] if args.key?(:fuel_burn_eea_strategy)
  @load_factors_ch_aviation_strategy = args[:load_factors_ch_aviation_strategy] if args.key?(:load_factors_ch_aviation_strategy)
  @load_factors_data = args[:load_factors_data] if args.key?(:load_factors_data)
  @load_factors_t100_strategy = args[:load_factors_t100_strategy] if args.key?(:load_factors_t100_strategy)
  @provenance_entry_type = args[:provenance_entry_type] if args.key?(:provenance_entry_type)
  @seat_area_ratio_iata_strategy = args[:seat_area_ratio_iata_strategy] if args.key?(:seat_area_ratio_iata_strategy)
  @source = args[:source] if args.key?(:source)
  @source_version = args[:source_version] if args.key?(:source_version)
end