Class: Google::Apis::TravelimpactmodelV1::FlightEmissionsDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/travelimpactmodel_v1/classes.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb

Overview

Details about the specific flight's emissions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FlightEmissionsDetails

Returns a new instance of FlightEmissionsDetails.



624
625
626
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 624

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contrails_impact_bucketString

Output only. The significance of contrails warming impact compared to the total CO2e emissions impact. Corresponds to the JSON property contrailsImpactBucket

Returns:

  • (String)


605
606
607
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 605

def contrails_impact_bucket
  @contrails_impact_bucket
end

#emissions_breakdownGoogle::Apis::TravelimpactmodelV1::EmissionsBreakdown

Details about the various emissions portions of the total emissions_grams_per_pax value. The value of the summed breakdowns should always equal emissions_grams_per_pax. Corresponds to the JSON property emissionsBreakdown



612
613
614
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 612

def emissions_breakdown
  @emissions_breakdown
end

#emissions_grams_per_paxGoogle::Apis::TravelimpactmodelV1::EmissionsGramsPerPax

Grouped emissions per seating class results. Corresponds to the JSON property emissionsGramsPerPax



617
618
619
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 617

def emissions_grams_per_pax
  @emissions_grams_per_pax
end

#sourceString

Output only. The source of the emissions data. Corresponds to the JSON property source

Returns:

  • (String)


622
623
624
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 622

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



629
630
631
632
633
634
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 629

def update!(**args)
  @contrails_impact_bucket = args[:contrails_impact_bucket] if args.key?(:contrails_impact_bucket)
  @emissions_breakdown = args[:emissions_breakdown] if args.key?(:emissions_breakdown)
  @emissions_grams_per_pax = args[:emissions_grams_per_pax] if args.key?(:emissions_grams_per_pax)
  @source = args[:source] if args.key?(:source)
end