Class: Google::Apis::TravelimpactmodelV1::FlightWithEmissions
- Inherits:
-
Object
- Object
- Google::Apis::TravelimpactmodelV1::FlightWithEmissions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/travelimpactmodel_v1/classes.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb
Overview
Direct flight with emission estimates.
Instance Attribute Summary collapse
-
#contrails_impact_bucket ⇒ String
Optional.
-
#easa_label_metadata ⇒ Google::Apis::TravelimpactmodelV1::EasaLabelMetadata
Metadata about the EASA Flight Emissions Label.
-
#emissions_grams_per_pax ⇒ Google::Apis::TravelimpactmodelV1::EmissionsGramsPerPax
Grouped emissions per seating class results.
-
#flight ⇒ Google::Apis::TravelimpactmodelV1::Flight
All details related to a single request item for a direct flight emission estimates.
-
#source ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FlightWithEmissions
constructor
A new instance of FlightWithEmissions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FlightWithEmissions
Returns a new instance of FlightWithEmissions.
700 701 702 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 700 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contrails_impact_bucket ⇒ String
Optional. The significance of contrails warming impact compared to the total
CO2e emissions impact.
Corresponds to the JSON property contrailsImpactBucket
677 678 679 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 677 def contrails_impact_bucket @contrails_impact_bucket end |
#easa_label_metadata ⇒ Google::Apis::TravelimpactmodelV1::EasaLabelMetadata
Metadata about the EASA Flight Emissions Label.
Corresponds to the JSON property easaLabelMetadata
682 683 684 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 682 def @easa_label_metadata end |
#emissions_grams_per_pax ⇒ Google::Apis::TravelimpactmodelV1::EmissionsGramsPerPax
Grouped emissions per seating class results.
Corresponds to the JSON property emissionsGramsPerPax
687 688 689 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 687 def emissions_grams_per_pax @emissions_grams_per_pax end |
#flight ⇒ Google::Apis::TravelimpactmodelV1::Flight
All details related to a single request item for a direct flight emission
estimates.
Corresponds to the JSON property flight
693 694 695 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 693 def flight @flight end |
#source ⇒ String
Optional. The source of the emissions data.
Corresponds to the JSON property source
698 699 700 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 698 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
705 706 707 708 709 710 711 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 705 def update!(**args) @contrails_impact_bucket = args[:contrails_impact_bucket] if args.key?(:contrails_impact_bucket) @easa_label_metadata = args[:easa_label_metadata] if args.key?(:easa_label_metadata) @emissions_grams_per_pax = args[:emissions_grams_per_pax] if args.key?(:emissions_grams_per_pax) @flight = args[:flight] if args.key?(:flight) @source = args[:source] if args.key?(:source) end |