Class: Google::Apis::TravelimpactmodelV1::EmissionsBreakdown
- Inherits:
-
Object
- Object
- Google::Apis::TravelimpactmodelV1::EmissionsBreakdown
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/travelimpactmodel_v1/classes.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb
Overview
Details about the various emissions portions of the total emissions_grams_per_pax value. The value of the summed breakdowns should always equal emissions_grams_per_pax.
Instance Attribute Summary collapse
-
#ttw_emissions_grams_per_pax ⇒ Google::Apis::TravelimpactmodelV1::EmissionsGramsPerPax
Grouped emissions per seating class results.
-
#wtt_emissions_grams_per_pax ⇒ Google::Apis::TravelimpactmodelV1::EmissionsGramsPerPax
Grouped emissions per seating class results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EmissionsBreakdown
constructor
A new instance of EmissionsBreakdown.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EmissionsBreakdown
Returns a new instance of EmissionsBreakdown.
325 326 327 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ttw_emissions_grams_per_pax ⇒ Google::Apis::TravelimpactmodelV1::EmissionsGramsPerPax
Grouped emissions per seating class results.
Corresponds to the JSON property ttwEmissionsGramsPerPax
318 319 320 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 318 def ttw_emissions_grams_per_pax @ttw_emissions_grams_per_pax end |
#wtt_emissions_grams_per_pax ⇒ Google::Apis::TravelimpactmodelV1::EmissionsGramsPerPax
Grouped emissions per seating class results.
Corresponds to the JSON property wttEmissionsGramsPerPax
323 324 325 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 323 def wtt_emissions_grams_per_pax @wtt_emissions_grams_per_pax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
330 331 332 333 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 330 def update!(**args) @ttw_emissions_grams_per_pax = args[:ttw_emissions_grams_per_pax] if args.key?(:ttw_emissions_grams_per_pax) @wtt_emissions_grams_per_pax = args[:wtt_emissions_grams_per_pax] if args.key?(:wtt_emissions_grams_per_pax) end |