Class: Google::Apis::TravelimpactmodelV1::EmissionsGramsPerPax
- Inherits:
-
Object
- Object
- Google::Apis::TravelimpactmodelV1::EmissionsGramsPerPax
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/travelimpactmodel_v1/classes.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb
Overview
Grouped emissions per seating class results.
Instance Attribute Summary collapse
-
#business ⇒ Fixnum
Emissions for one passenger in business class in grams.
-
#economy ⇒ Fixnum
Emissions for one passenger in economy class in grams.
-
#first ⇒ Fixnum
Emissions for one passenger in first class in grams.
-
#premium_economy ⇒ Fixnum
Emissions for one passenger in premium economy class in grams.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EmissionsGramsPerPax
constructor
A new instance of EmissionsGramsPerPax.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EmissionsGramsPerPax
Returns a new instance of EmissionsGramsPerPax.
368 369 370 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 368 def initialize(**args) update!(**args) end |
Instance Attribute Details
#business ⇒ Fixnum
Emissions for one passenger in business class in grams. This field is always
computed and populated, regardless of whether the aircraft has business class
seats or not.
Corresponds to the JSON property business
345 346 347 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 345 def business @business end |
#economy ⇒ Fixnum
Emissions for one passenger in economy class in grams. This field is always
computed and populated, regardless of whether the aircraft has economy class
seats or not.
Corresponds to the JSON property economy
352 353 354 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 352 def economy @economy end |
#first ⇒ Fixnum
Emissions for one passenger in first class in grams. This field is always
computed and populated, regardless of whether the aircraft has first class
seats or not.
Corresponds to the JSON property first
359 360 361 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 359 def first @first end |
#premium_economy ⇒ Fixnum
Emissions for one passenger in premium economy class in grams. This field is
always computed and populated, regardless of whether the aircraft has premium
economy class seats or not.
Corresponds to the JSON property premiumEconomy
366 367 368 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 366 def premium_economy @premium_economy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
373 374 375 376 377 378 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 373 def update!(**args) @business = args[:business] if args.key?(:business) @economy = args[:economy] if args.key?(:economy) @first = args[:first] if args.key?(:first) @premium_economy = args[:premium_economy] if args.key?(:premium_economy) end |