Class: Google::Apis::TravelimpactmodelV1::EmissionsProvenance
- Inherits:
-
Object
- Object
- Google::Apis::TravelimpactmodelV1::EmissionsProvenance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/travelimpactmodel_v1/classes.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb
Overview
Information about the provenance of the data used to calculate emissions
estimates, including contributing factors and their data sources. In
provenance_entries, provenance_entry_type acts as the "key" identifying the
contributing factor, and there is always only one entry per entry type. The
remaining fields in each entry describe that specific entry type and may or
may not be populated depending on the contributing factor and available data.
Instance Attribute Summary collapse
-
#provenance_entries ⇒ Array<Google::Apis::TravelimpactmodelV1::EmissionsProvenanceEntry>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EmissionsProvenance
constructor
A new instance of EmissionsProvenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EmissionsProvenance
Returns a new instance of EmissionsProvenance.
436 437 438 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 436 def initialize(**args) update!(**args) end |
Instance Attribute Details
#provenance_entries ⇒ Array<Google::Apis::TravelimpactmodelV1::EmissionsProvenanceEntry>
Output only. All contributing factors used to calculate emissions. Each entry
type (provenance_entry_type) acts as a "key" identifying the factor, with
always only one entry per entry type. The remaining fields describe that
specific factor and may or may not be populated.
Corresponds to the JSON property provenanceEntries
434 435 436 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 434 def provenance_entries @provenance_entries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
441 442 443 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 441 def update!(**args) @provenance_entries = args[:provenance_entries] if args.key?(:provenance_entries) end |