Class: Google::Apis::TravelimpactmodelV1::EmissionsProvenance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/travelimpactmodel_v1/classes.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb

Overview

Information about the provenance of the data used to calculate emissions estimates, including contributing factors and their data sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EmissionsProvenance

Returns a new instance of EmissionsProvenance.



425
426
427
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#provenance_entriesArray<Google::Apis::TravelimpactmodelV1::EmissionsProvenanceEntry>

Output only. All contributing factors used to calculate emissions. Corresponds to the JSON property provenanceEntries



423
424
425
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 423

def provenance_entries
  @provenance_entries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



430
431
432
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 430

def update!(**args)
  @provenance_entries = args[:provenance_entries] if args.key?(:provenance_entries)
end