Class: Google::Apis::TravelimpactmodelV1::EmissionsProvenanceEntry
- Inherits:
-
Object
- Object
- Google::Apis::TravelimpactmodelV1::EmissionsProvenanceEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/travelimpactmodel_v1/classes.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb
Overview
Details about a single contributing factor in emissions calculations.
Instance Attribute Summary collapse
-
#cargo_mass_fraction_data ⇒ Float
Output only.
-
#cargo_mass_fraction_t100_strategy ⇒ String
Output only.
-
#data_category ⇒ String
Output only.
-
#distance_adjustment_strategy ⇒ String
Output only.
-
#estimated_flight_distance_km ⇒ Fixnum
Output only.
-
#fuel_burn_eea_strategy ⇒ String
Output only.
-
#load_factors_ch_aviation_strategy ⇒ String
Output only.
-
#load_factors_data ⇒ Float
Output only.
-
#load_factors_t100_strategy ⇒ String
Output only.
-
#provenance_entry_type ⇒ String
Output only.
-
#seat_area_ratio_data ⇒ Google::Apis::TravelimpactmodelV1::SeatAreaRatioData
Seat area ratio data values.
-
#seat_area_ratio_iata_strategy ⇒ String
Output only.
-
#source ⇒ String
Output only.
-
#source_version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EmissionsProvenanceEntry
constructor
A new instance of EmissionsProvenanceEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EmissionsProvenanceEntry
Returns a new instance of EmissionsProvenanceEntry.
515 516 517 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 515 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cargo_mass_fraction_data ⇒ Float
Output only. The cargo mass fraction value. If not set, the cargo mass
fraction value is not available.
Corresponds to the JSON property cargoMassFractionData
443 444 445 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 443 def cargo_mass_fraction_data @cargo_mass_fraction_data end |
#cargo_mass_fraction_t100_strategy ⇒ String
Output only. Strategy for T100 cargo mass fraction.
Corresponds to the JSON property cargoMassFractionT100Strategy
448 449 450 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 448 def cargo_mass_fraction_t100_strategy @cargo_mass_fraction_t100_strategy end |
#data_category ⇒ String
Output only. Data category of the data source.
Corresponds to the JSON property dataCategory
453 454 455 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 453 def data_category @data_category end |
#distance_adjustment_strategy ⇒ String
Output only. Strategy for distance adjustment.
Corresponds to the JSON property distanceAdjustmentStrategy
458 459 460 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 458 def distance_adjustment_strategy @distance_adjustment_strategy end |
#estimated_flight_distance_km ⇒ Fixnum
Output only. The estimated distance flown in CCD flight phase in kilometers
value calculated using the distance adjustment factor (DAF). If not set, the
estimated flight distance value is not available.
Corresponds to the JSON property estimatedFlightDistanceKm
465 466 467 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 465 def estimated_flight_distance_km @estimated_flight_distance_km end |
#fuel_burn_eea_strategy ⇒ String
Output only. Strategy for EEA fuel burn.
Corresponds to the JSON property fuelBurnEeaStrategy
470 471 472 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 470 def fuel_burn_eea_strategy @fuel_burn_eea_strategy end |
#load_factors_ch_aviation_strategy ⇒ String
Output only. Strategy for CH Aviation load factors.
Corresponds to the JSON property loadFactorsChAviationStrategy
475 476 477 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 475 def load_factors_ch_aviation_strategy @load_factors_ch_aviation_strategy end |
#load_factors_data ⇒ Float
Output only. The load factors data value. If not set, the load factors value
is not available.
Corresponds to the JSON property loadFactorsData
481 482 483 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 481 def load_factors_data @load_factors_data end |
#load_factors_t100_strategy ⇒ String
Output only. Strategy for T100 load factors.
Corresponds to the JSON property loadFactorsT100Strategy
486 487 488 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 486 def load_factors_t100_strategy @load_factors_t100_strategy end |
#provenance_entry_type ⇒ String
Output only. The type of the provenance entry.
Corresponds to the JSON property provenanceEntryType
491 492 493 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 491 def provenance_entry_type @provenance_entry_type end |
#seat_area_ratio_data ⇒ Google::Apis::TravelimpactmodelV1::SeatAreaRatioData
Seat area ratio data values. Economy is always 1.0 and serves as the reference
point; other class values are relative to economy. All 4 fields are always set
whether the seating class exists on the aircraft or not.
Corresponds to the JSON property seatAreaRatioData
498 499 500 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 498 def seat_area_ratio_data @seat_area_ratio_data end |
#seat_area_ratio_iata_strategy ⇒ String
Output only. Strategy for IATA seat area ratios.
Corresponds to the JSON property seatAreaRatioIataStrategy
503 504 505 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 503 def seat_area_ratio_iata_strategy @seat_area_ratio_iata_strategy end |
#source ⇒ String
Output only. The source of the data.
Corresponds to the JSON property source
508 509 510 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 508 def source @source end |
#source_version ⇒ String
Output only. The version of the source data. For example, "2025/04".
Corresponds to the JSON property sourceVersion
513 514 515 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 513 def source_version @source_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 520 def update!(**args) @cargo_mass_fraction_data = args[:cargo_mass_fraction_data] if args.key?(:cargo_mass_fraction_data) @cargo_mass_fraction_t100_strategy = args[:cargo_mass_fraction_t100_strategy] if args.key?(:cargo_mass_fraction_t100_strategy) @data_category = args[:data_category] if args.key?(:data_category) @distance_adjustment_strategy = args[:distance_adjustment_strategy] if args.key?(:distance_adjustment_strategy) @estimated_flight_distance_km = args[:estimated_flight_distance_km] if args.key?(:estimated_flight_distance_km) @fuel_burn_eea_strategy = args[:fuel_burn_eea_strategy] if args.key?(:fuel_burn_eea_strategy) @load_factors_ch_aviation_strategy = args[:load_factors_ch_aviation_strategy] if args.key?(:load_factors_ch_aviation_strategy) @load_factors_data = args[:load_factors_data] if args.key?(:load_factors_data) @load_factors_t100_strategy = args[:load_factors_t100_strategy] if args.key?(:load_factors_t100_strategy) @provenance_entry_type = args[:provenance_entry_type] if args.key?(:provenance_entry_type) @seat_area_ratio_data = args[:seat_area_ratio_data] if args.key?(:seat_area_ratio_data) @seat_area_ratio_iata_strategy = args[:seat_area_ratio_iata_strategy] if args.key?(:seat_area_ratio_iata_strategy) @source = args[:source] if args.key?(:source) @source_version = args[:source_version] if args.key?(:source_version) end |