Class: Google::Apis::TravelimpactmodelV1::FlightEmissionsDetails
- Inherits:
-
Object
- Object
- Google::Apis::TravelimpactmodelV1::FlightEmissionsDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/travelimpactmodel_v1/classes.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb
Overview
Details about the specific flight's emissions.
Instance Attribute Summary collapse
-
#contrails_impact_bucket ⇒ String
Output only.
-
#emissions_breakdown ⇒ Google::Apis::TravelimpactmodelV1::EmissionsBreakdown
Details about the various emissions portions of the total emissions_grams_per_pax value.
-
#emissions_grams_per_pax ⇒ Google::Apis::TravelimpactmodelV1::EmissionsGramsPerPax
Grouped emissions per seating class results.
-
#source ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FlightEmissionsDetails
constructor
A new instance of FlightEmissionsDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FlightEmissionsDetails
Returns a new instance of FlightEmissionsDetails.
616 617 618 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contrails_impact_bucket ⇒ String
Output only. The significance of contrails warming impact compared to the
total CO2e emissions impact.
Corresponds to the JSON property contrailsImpactBucket
597 598 599 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 597 def contrails_impact_bucket @contrails_impact_bucket end |
#emissions_breakdown ⇒ Google::Apis::TravelimpactmodelV1::EmissionsBreakdown
Details about the various emissions portions of the total
emissions_grams_per_pax value. The value of the summed breakdowns should
always equal emissions_grams_per_pax.
Corresponds to the JSON property emissionsBreakdown
604 605 606 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 604 def emissions_breakdown @emissions_breakdown end |
#emissions_grams_per_pax ⇒ Google::Apis::TravelimpactmodelV1::EmissionsGramsPerPax
Grouped emissions per seating class results.
Corresponds to the JSON property emissionsGramsPerPax
609 610 611 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 609 def emissions_grams_per_pax @emissions_grams_per_pax end |
#source ⇒ String
Output only. The source of the emissions data.
Corresponds to the JSON property source
614 615 616 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 614 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
621 622 623 624 625 626 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 621 def update!(**args) @contrails_impact_bucket = args[:contrails_impact_bucket] if args.key?(:contrails_impact_bucket) @emissions_breakdown = args[:emissions_breakdown] if args.key?(:emissions_breakdown) @emissions_grams_per_pax = args[:emissions_grams_per_pax] if args.key?(:emissions_grams_per_pax) @source = args[:source] if args.key?(:source) end |