Class: Google::Apis::TravelimpactmodelV1::FlightWithEmissions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/travelimpactmodel_v1/classes.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb

Overview

Direct flight with emission estimates.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FlightWithEmissions

Returns a new instance of FlightWithEmissions.



391
392
393
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 391

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contrails_impact_bucketString

Optional. The significance of contrails warming impact compared to the total CO2e emissions impact. Corresponds to the JSON property contrailsImpactBucket

Returns:

  • (String)


368
369
370
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 368

def contrails_impact_bucket
  @contrails_impact_bucket
end

#easa_label_metadataGoogle::Apis::TravelimpactmodelV1::EasaLabelMetadata

Metadata about the EASA Flight Emissions Label. Corresponds to the JSON property easaLabelMetadata



373
374
375
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 373

def 
  @easa_label_metadata
end

#emissions_grams_per_paxGoogle::Apis::TravelimpactmodelV1::EmissionsGramsPerPax

Grouped emissions per seating class results. Corresponds to the JSON property emissionsGramsPerPax



378
379
380
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 378

def emissions_grams_per_pax
  @emissions_grams_per_pax
end

#flightGoogle::Apis::TravelimpactmodelV1::Flight

All details related to a single request item for a direct flight emission estimates. Corresponds to the JSON property flight



384
385
386
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 384

def flight
  @flight
end

#sourceString

Optional. The source of the emissions data. Corresponds to the JSON property source

Returns:

  • (String)


389
390
391
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 389

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



396
397
398
399
400
401
402
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 396

def update!(**args)
  @contrails_impact_bucket = args[:contrails_impact_bucket] if args.key?(:contrails_impact_bucket)
  @easa_label_metadata = args[:easa_label_metadata] if args.key?(:easa_label_metadata)
  @emissions_grams_per_pax = args[:emissions_grams_per_pax] if args.key?(:emissions_grams_per_pax)
  @flight = args[:flight] if args.key?(:flight)
  @source = args[:source] if args.key?(:source)
end