Class: Google::Apis::TravelimpactmodelV1::ModelVersion
- Inherits:
-
Object
- Object
- Google::Apis::TravelimpactmodelV1::ModelVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/travelimpactmodel_v1/classes.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb,
lib/google/apis/travelimpactmodel_v1/representations.rb
Overview
Travel Impact Model version. For more information about the model versioning see GitHub.
Instance Attribute Summary collapse
-
#dated ⇒ String
Dated versions: Model datasets are recreated with refreshed input data but no change to the algorithms regularly.
-
#major ⇒ Fixnum
Major versions: Major changes to methodology (e.g. adding new data sources to the model that lead to major output changes).
-
#minor ⇒ Fixnum
Minor versions: Changes to the model that, while being consistent across schema versions, change the model parameters or implementation.
-
#patch ⇒ Fixnum
Patch versions: Implementation changes meant to address bugs or inaccuracies in the model implementation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ModelVersion
constructor
A new instance of ModelVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ModelVersion
Returns a new instance of ModelVersion.
462 463 464 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 462 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dated ⇒ String
Dated versions: Model datasets are recreated with refreshed input data but no
change to the algorithms regularly.
Corresponds to the JSON property dated
439 440 441 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 439 def dated @dated end |
#major ⇒ Fixnum
Major versions: Major changes to methodology (e.g. adding new data sources to
the model that lead to major output changes). Such changes will be infrequent
and announced well in advance. Might involve API version changes, which will
respect Google Cloud API guidelines
Corresponds to the JSON property major
448 449 450 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 448 def major @major end |
#minor ⇒ Fixnum
Minor versions: Changes to the model that, while being consistent across
schema versions, change the model parameters or implementation.
Corresponds to the JSON property minor
454 455 456 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 454 def minor @minor end |
#patch ⇒ Fixnum
Patch versions: Implementation changes meant to address bugs or inaccuracies
in the model implementation.
Corresponds to the JSON property patch
460 461 462 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 460 def patch @patch end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
467 468 469 470 471 472 |
# File 'lib/google/apis/travelimpactmodel_v1/classes.rb', line 467 def update!(**args) @dated = args[:dated] if args.key?(:dated) @major = args[:major] if args.key?(:major) @minor = args[:minor] if args.key?(:minor) @patch = args[:patch] if args.key?(:patch) end |